@@ -6,7 +6,6 @@ use Safe;
 use Lemonldap::NG::Common::Safelib;    #link protected safe Safe object
 use constant SAFEWRAP => ( Safe->can("wrap_code_ref") ? 1 : 0 );
 use Mouse;
-use Lemonldap::NG::Handler::Main::Logger;
 
 has customFunctions => ( is => 'rw', isa => 'Maybe[Str]' );
 
@@ -16,29 +15,30 @@ has jail => ( is => 'rw' );
 
 has error => ( is => 'rw' );
 
-our $VERSION = '1.9.9';
-
-use Lemonldap::NG::Handler::Main '$datas', '$tsv';
-use Lemonldap::NG::Handler::API ':functions';
+our $VERSION = '1.9.99_02';
 
 ## @imethod protected build_jail()
 # Build and return the security jail used to compile rules and headers.
 # @return Safe object
 sub build_jail {
-    my $self = shift;
+    my ( $self, $api ) = @_;
 
     return $self->jail
-      if ( $self->jail
-        && $self->jail->useSafeJail == $self->useSafeJail
-        && $self->jail->customFunctions == $self->customFunctions );
+      if (  $self->jail
+        and $self->jail->useSafeJail
+        and $self->jail->customFunctions
+        and $self->useSafeJail
+        and $self->customFunctions
+        and $self->jail->useSafeJail == $self->useSafeJail
+        and $self->jail->customFunctions == $self->customFunctions );
 
     $self->useSafeJail(1) unless defined $self->useSafeJail;
 
     my @t =
       $self->customFunctions ? split( /\s+/, $self->customFunctions ) : ();
     foreach (@t) {
-        Lemonldap::NG::Handler::Main::Logger->lmLog( "Custom function : $_",
-            'debug' );
+        no warnings 'redefine';
+        $api->logger->debug("Custom function : $_");
         my $sub = $_;
         unless (/::/) {
             $sub = "$self\::$_";
@@ -48,16 +48,15 @@ sub build_jail {
         }
         next if ( $self->can($_) );
         eval "sub $_ {
-            my \$uri = Lemonldap::NG::Handler::API::${Lemonldap::NG::Handler::API::mode}::uri_with_args();
+            my \$uri = $api\::uri_with_args();
             return $sub(\$uri,\@_)
         }";
-        Lemonldap::NG::Handler::Main::Logger->lmLog( $@, 'error' ) if ($@);
+        $api->logger->error($@) if ($@);
         $_ = "&$_";
     }
 
     if ( $self->useSafeJail ) {
         $self->jail( Safe->new );
-        $self->jail->share_from( 'main', ['%ENV'] );
     }
     else {
         $self->jail($self);
@@ -67,33 +66,37 @@ sub build_jail {
     $self->jail->share_from( 'Lemonldap::NG::Common::Safelib',
         $Lemonldap::NG::Common::Safelib::functions );
 
-    $self->jail->share_from( 'Lemonldap::NG::Handler::Main',
-        [ '$tsv', '$datas' ] );
     $self->jail->share_from(
-        'Lemonldap::NG::Handler::API',
+        $api,
         [
             qw( &hostname &remote_ip &uri &uri_with_args
-              &unparsed_uri &args &method &header_in   )
+              &unparsed_uri &args &method &header_in &env )
         ]
     );
-    $self->jail->share_from( __PACKAGE__, [ @t, '&encrypt' ] );
+    $self->jail->share_from( __PACKAGE__, [ @t, '&encrypt', '&token' ] );
     $self->jail->share_from( 'MIME::Base64', ['&encode_base64'] );
+    $self->jail->share_from( 'Lemonldap::NG::Handler::Main', ['$_v'] );
 
     # Initialize cryptographic functions to be able to use them in jail.
-    eval { encrypt('a') };
+    eval { token('a') };
 
     return $self->jail;
 }
 
 # Import crypto methods for jail
 sub encrypt {
-    return $tsv->{cipher}->encrypt(@_);
+    return &Lemonldap::NG::Handler::Main::tsv->{cipher}->encrypt(@_);
+}
+
+sub token {
+    return encrypt( join( ':', time, @_ ) );
 }
 
 ## @method reval
 # Fake reval method if useSafeJail is off
 sub reval {
     my ( $self, $e ) = @_;
+
     my $res = eval $e;
     if ($@) {
         $self->error($@);
@@ -144,19 +147,18 @@ sub share_from {
 sub jail_reval {
     my ( $self, $reval ) = @_;
 
+    $reval =~ s/\$ENV\{/&env()->\{/g;
+
     # if nothing is returned by reval, add the return statement to
     # the "no safe wrap" reval
-    my $nosw_reval = $reval;
-    if ( $reval !~ /^sub\{return\(.*\}$/ ) {
-        $nosw_reval =~ s/^sub\{(.*)\}$/sub{return($1)}/;
-    }
 
     my $res;
     eval {
         $res = (
             SAFEWRAP
+              and $self->useSafeJail
             ? $self->jail->wrap_code_ref( $self->jail->reval($reval) )
-            : $self->jail->reval($nosw_reval)
+            : $self->jail->reval($reval)
         );
     };
     if ($@) {
