@@ -2,15 +2,17 @@ package Lemonldap::NG::Handler::PSGI::Router;
 
 use 5.10.0;
 use Mouse;
+require Lemonldap::NG::Handler::PSGI::Main;
 
-extends 'Lemonldap::NG::Handler::PSGI::Base',
+extends 'Lemonldap::NG::Handler::Lib::PSGI',
   'Lemonldap::NG::Common::PSGI::Router';
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.99_02';
 
 sub init {
-    my $tmp = $_[0]->Lemonldap::NG::Common::PSGI::Router::init( $_[1] )
-      and $_[0]->Lemonldap::NG::Handler::PSGI::Base::init( $_[1] );
+    $_[0]->api('Lemonldap::NG::Handler::PSGI::Main');
+    my $tmp = ( $_[0]->Lemonldap::NG::Common::PSGI::Router::init( $_[1] )
+          and $_[0]->Lemonldap::NG::Handler::Lib::PSGI::init( $_[1] ) );
     return $tmp;
 }
 
@@ -123,13 +125,7 @@ L<Lemonldap::NG::Common::PSGI::Request>, L<HTML::Template>,
 
 =over
 
-=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
-
-=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
-
-=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
-=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+=item LemonLDAP::NG team L<http://lemonldap-ng.org/team>
 
 =back
 
@@ -145,13 +141,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-=over
-
-=item Copyright (C) 2015-2016 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
-=item Copyright (C) 2015-2016 by Clément Oudot, E<lt>clem.oudot@gmail.comE<gt>
-
-=back
+See COPYING file for details.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
